searchData={"items":[{"type":"module","title":"Slip39","doc":"Elixir implementation of the [SLIP-0039 : Shamir's Secret-Sharing for Mnemonic Codes](https://github.com/satoshilabs/slips/blob/master/slip-0039.md).\n\nThis implementation is largely inspired by the [reference implementation](http://github.com/trezor/python-shamir-mnemonic/).\n\nThis work is very in progress. Any contribution is welcome.\n\n> ##","ref":"Slip39.html"},{"type":"module","title":"DISCLAIMER {: .warning} - Slip39","doc":">\n>This module is supplied as is. Since it has not been audited and can\n>contains bugs, it should not be used to manipulate valuable secrets. If you decide to\n>ignore this warning, use basic OPSEC common sense and, at the very least, use a\n>computer booted on a USB key, then taken offline during calls to the functions of this\n>module. In addition, each mnemonic generated must never be stored in an electronic format\n>and must be carefully re-read. In any case, its/their authors cannot be held responsible\n>for any loss of data or its financial consequences resulting from the direct or indirect\n>use of this module.","ref":"Slip39.html#module-disclaimer-warning"},{"type":"function","title":"Slip39.combine_mnemonics/2","doc":"Combine mnemonic shares to obtain the master secret which was previously split\nusing Shamir's secret sharing scheme.\n\nThis is the user-friendly method to recover a backed-up secret optionally protected\nby a passphrase.","ref":"Slip39.html#combine_mnemonics/2"},{"type":"function","title":"Examples - Slip39.combine_mnemonics/2","doc":"iex(1)> [\"pajamas lungs academic acid thank snapshot scramble should mason vintage lilac infant rocky dismiss blue spider recover step alcohol that early pregnant guilt\",\"pajamas lungs academic agency firefly order hearing describe forbid welfare emphasis true ting pregnant solution genre source graduate idea alcohol squeeze luxury elegant\",\"pajamas lungs academic always minister evening lunch prospect duke license realize evening armed laser oven warmth helpful slap trial home sunlight trend standard\"]\n      iex(2)> |> Slip39.combine_mnemonics\n      \"Long life to Elixir!\"","ref":"Slip39.html#combine_mnemonics/2-examples"},{"type":"function","title":"Slip39.generate_mnemonics!/3","doc":"Split a master secret into mnemonic shares using Shamir's secret sharing scheme\nusing a single threshold/count group and no passphrase encryption.","ref":"Slip39.html#generate_mnemonics!/3"},{"type":"function","title":"Examples - Slip39.generate_mnemonics!/3","doc":"Since random data is inserted into mnemonics when they are generated\nyou won't have the same output when running this example.\n\n    iex(1)>  Slip39.generate_mnemonics!(3,5,\"Long life to Elixir!\")\n    [\n      [\"formal discuss academic acne rebound violence class ultimate float envelope smear costume fumes medical license practice eclipse language auction check coding lamp lecture\",\n      \"formal discuss academic agree debut bucket both salt cage home improve purchase burden amuse paces distance acid destroy plan piece alive upstairs being\",\n      \"formal discuss academic amazing database devote software peasant either profile junction object disaster velvet aspect regret adapt axle excuse advocate flip eyebrow friar\",\n      \"formal discuss academic arcade pitch subject thunder math airport maiden season acquire ladle infant being criminal edge forward trouble loan jacket system smirk\",\n      \"formal discuss academic axle overall phrase treat thank branch transfer wireless faint award skin jerky paid twice fake exact echo saver steady ruler\"]\n    ]","ref":"Slip39.html#generate_mnemonics!/3-examples"},{"type":"function","title":"Slip39.generate_mnemonics!/5","doc":"Split a master secret into mnemonic shares using Shamir's secret sharing scheme.\n\nThe supplied Master Secret is encrypted by the passphrase (empty passphrase is used\nif none is provided) and split into a set of mnemonic shares.\n\nThis function allows a two level group definition (see example).","ref":"Slip39.html#generate_mnemonics!/5"},{"type":"function","title":"Examples - Slip39.generate_mnemonics!/5","doc":"Alice want to backup her secret. She will keep two share for herself, in separate vault,\nbut in case she loose one of them, she wants to be able to recover her secret, by recovering\nany three share she had given to five of her best friends.\n\nNote that since random data is inserted into mnemonics when they are generated you won't have\nthe same output when running this example.\n\n    iex(1)> groups = Slip39.generate_mnemonics!(2, [{1,1}, {1,1}, {3,5}], \"Long life to Elixir!\", \"\")\n    [\n      [\"window provide acrobat leader include tidy estate promise holiday earth trip solution cubic math teammate auction bracelet fishing walnut faint minister material endless\"],\n      [\"window provide beard leader fumes scholar primary elder flavor theory papa insect holiday survive beam cards laundry flexible lunch presence rebuild emerald exhaust\"],\n      [\"window provide ceramic learn charity industry aviation sack package priority umbrella forbid triumph webcam starting firefly problem vocal improve task sympathy spray herd\",\n      \"window provide ceramic lips lecture airport hobo legal declare describe says source quiet golden pitch society genius raisin ceiling admit luxury empty license\",\n      \"window provide ceramic luxury diet diploma bumpy cowboy usher building drove leaves rapids trust squeeze salt mule presence pupal disease public rainbow afraid\",\n      \"window provide ceramic march mule ending jerky hanger frozen lift beyond antenna unknown intend platform employer focus unknown taught tidy tidy clinic typical\",\n      \"window provide ceramic method clay carve stadium laden tenant rhythm river much security isolate fumes axis calcium expect pulse petition miracle senior else\"]\n    ]\n\n    ...(2)> to_be_stored_in_alice_vault1 = groups |> Enum.at(0)\n    [\"window provide acrobat leader include tidy estate promise holiday earth trip solution cubic math teammate auction bracelet fishing walnut faint minister material endless\"]\n\n    ...(3)> to_be_stored_in_alice_vault2 = groups |> Enum.at(1)\n    [\"window provide beard leader fumes scholar primary elder flavor theory papa insect holiday survive beam cards laundry flexible lunch presence rebuild emerald exhaust\"]\n\n    ...(4)> to_be_given_to_five_friends = groups |> Enum.at(2)\n    [\"window provide ceramic learn charity industry aviation sack package priority umbrella forbid triumph webcam starting firefly problem vocal improve task sympathy spray herd\",\n    \"window provide ceramic lips lecture airport hobo legal declare describe says source quiet golden pitch society genius raisin ceiling admit luxury empty license\",\n    \"window provide ceramic luxury diet diploma bumpy cowboy usher building drove leaves rapids trust squeeze salt mule presence pupal disease public rainbow afraid\",\n    \"window provide ceramic march mule ending jerky hanger frozen lift beyond antenna unknown intend platform employer focus unknown taught tidy tidy clinic typical\",\n    \"window provide ceramic method clay carve stadium laden tenant rhythm river much security isolate fumes axis calcium expect pulse petition miracle senior else\"]","ref":"Slip39.html#generate_mnemonics!/5-examples"},{"type":"module","title":"Slip39.Constants","doc":"","ref":"Slip39.Constants.html"},{"type":"function","title":"Slip39.Constants.get!/1","doc":"","ref":"Slip39.Constants.html#get!/1"},{"type":"module","title":"Slip39.Cypher","doc":"","ref":"Slip39.Cypher.html"},{"type":"function","title":"Slip39.Cypher.decrypt/4","doc":"","ref":"Slip39.Cypher.html#decrypt/4"},{"type":"function","title":"Slip39.Cypher.encrypt/4","doc":"","ref":"Slip39.Cypher.html#encrypt/4"},{"type":"module","title":"Slip39.Rs1024","doc":"","ref":"Slip39.Rs1024.html"},{"type":"function","title":"Slip39.Rs1024.create_checksum/1","doc":"Create a checksum (see spec). Data passed as argument should\nbe a bitstring of multiple of radix_size, that is 10\n\n    iex(1)> Slip39.Rs1024.create_checksum(\"Long life to Elixir!\")\n    <<183, 154, 93, 32::size(6)>>","ref":"Slip39.Rs1024.html#create_checksum/1"},{"type":"function","title":"Slip39.Rs1024.is_checksum_valid?/1","doc":"Verify that the given data, included at the end\nof the data, is valid (see spec).\n\n    iex(1)> checksum = Slip39.Rs1024.create_checksum(\"Long life to Elixir!\")\n    <<183, 154, 93, 32::size(6)>>\n    iex(2)> Slip39.Rs1024.is_checksum_valid?(<<\"Long life to Elixir!\"::bitstring, checksum::bitstring>>)\n    true\n    iex(3)>  Slip39.Rs1024.is_checksum_valid?(<<\"Long life to Elixir?\"::bitstring, checksum::bitstring>>)\n    false","ref":"Slip39.Rs1024.html#is_checksum_valid?/1"},{"type":"module","title":"Slip39.Shamir","doc":"","ref":"Slip39.Shamir.html"},{"type":"function","title":"Slip39.Shamir.compute_exp_log_tables/0","doc":"","ref":"Slip39.Shamir.html#compute_exp_log_tables/0"},{"type":"function","title":"Slip39.Shamir.create_digest/2","doc":"","ref":"Slip39.Shamir.html#create_digest/2"},{"type":"function","title":"Slip39.Shamir.decode_mnemonics/1","doc":"","ref":"Slip39.Shamir.html#decode_mnemonics/1"},{"type":"function","title":"Slip39.Shamir.interpolate/2","doc":"","ref":"Slip39.Shamir.html#interpolate/2"},{"type":"function","title":"Slip39.Shamir.random_identifier/0","doc":"","ref":"Slip39.Shamir.html#random_identifier/0"},{"type":"function","title":"Slip39.Shamir.recover_ems/1","doc":"","ref":"Slip39.Shamir.html#recover_ems/1"},{"type":"function","title":"Slip39.Shamir.recover_secret/2","doc":"","ref":"Slip39.Shamir.html#recover_secret/2"},{"type":"function","title":"Slip39.Shamir.split_ems!/5","doc":"","ref":"Slip39.Shamir.html#split_ems!/5"},{"type":"function","title":"Slip39.Shamir.split_secret!/3","doc":"","ref":"Slip39.Shamir.html#split_secret!/3"},{"type":"module","title":"Slip39.Share","doc":"Represents a single mnemonic share","ref":"Slip39.Share.html"},{"type":"function","title":"Slip39.Share.binary_to_mnemonic/1","doc":"","ref":"Slip39.Share.html#binary_to_mnemonic/1"},{"type":"function","title":"Slip39.Share.decode!/1","doc":"This function will decode a mnemonic string into a `Slip39.Share` struct.","ref":"Slip39.Share.html#decode!/1"},{"type":"function","title":"Example - Slip39.Share.decode!/1","doc":"iex(1)> Slip39.Share.decode!(\"kernel leader acrobat romp camera unusual fawn engage revenue total blimp quiet muscle clinic slush mouse watch estimate custody glimpse\")\n    %Slip39.Share{\n      identifier: 15856,\n      iteration_exponent: 0,\n      group_index: 0,\n      group_threshold: 2,\n      group_count: 4,\n      member_index: 0,\n      member_threshold: 1,\n      data: <<116, 239, 149, 20, 122, 245, 231, 69, 107, 62, 90, 37, 51, 169, 87,\n        227>>\n    }","ref":"Slip39.Share.html#decode!/1-example"},{"type":"function","title":"Slip39.Share.encode!/1","doc":"This function will encode a `Slip39.Share` struct into a mnemonic string.","ref":"Slip39.Share.html#encode!/1"},{"type":"function","title":"Slip39.Share.get_common_parameters/1","doc":"","ref":"Slip39.Share.html#get_common_parameters/1"},{"type":"function","title":"Slip39.Share.get_group_parameters/1","doc":"","ref":"Slip39.Share.html#get_group_parameters/1"},{"type":"function","title":"Slip39.Share.get_raw_shares/1","doc":"","ref":"Slip39.Share.html#get_raw_shares/1"},{"type":"function","title":"Slip39.Share.mnemonic_to_binary/1","doc":"","ref":"Slip39.Share.html#mnemonic_to_binary/1"},{"type":"function","title":"Slip39.Share.mnemonic_to_indices/1","doc":"","ref":"Slip39.Share.html#mnemonic_to_indices/1"},{"type":"module","title":"Slip39.Share.CommonParameters","doc":"Parameters that are common to all shares of a master secret.","ref":"Slip39.Share.CommonParameters.html"},{"type":"module","title":"Slip39.Share.GroupParameters","doc":"Parameters that are common to all shares of a master secret, which belong to the same group.","ref":"Slip39.Share.GroupParameters.html"},{"type":"module","title":"Slip39.Share.RawShare","doc":"","ref":"Slip39.Share.RawShare.html"},{"type":"module","title":"Slip39.Utils","doc":"","ref":"Slip39.Utils.html"},{"type":"function","title":"Slip39.Utils.bits_to_bytes/1","doc":"Round up bit count to whole bytes.\n\n    iex(1)> Slip39.Utils.bits_to_bytes(9)\n    2","ref":"Slip39.Utils.html#bits_to_bytes/1"},{"type":"function","title":"Slip39.Utils.chunk_bits/2","doc":"Chunk the given bitstring into an array of bitstring\nof n length.\n\n    iex(1)> Slip39.Utils.chunk_bits(<<1::1, 1::1, 1::1, 1::1>>,2)\n    [<<3::size(2)>>, <<3::size(2)>>]","ref":"Slip39.Utils.html#chunk_bits/2"},{"type":"function","title":"Slip39.Utils.enum_to_indexed_map/1","doc":"When an enum needs to be accessed by its index, this function gives\nan efficient way and cleaner syntax to do it.\n\n    iex(1)> my_data = [\"zero\", \"one\", \"two\"]\n    [\"zero\", \"one\", \"two\"]\n    iex(2)> my_indexed_data = Slip39.Utils.enum_to_indexed_map(my_data)\n    %{0 => \"zero\", 1 => \"one\", 2 => \"two\"}\n    iex(3)> my_indexed_data[2]\n    \"two\"","ref":"Slip39.Utils.html#enum_to_indexed_map/1"},{"type":"function","title":"Slip39.Utils.is_string_only_ascii/1","doc":"","ref":"Slip39.Utils.html#is_string_only_ascii/1"},{"type":"function","title":"Slip39.Utils.nearest_upper_multiple/2","doc":"Round up an integer to the next multiple given a second argument\n\n    iex(1)> Slip39.Utils.nearest_upper_multiple(41, 10)\n    50","ref":"Slip39.Utils.html#nearest_upper_multiple/2"},{"type":"function","title":"Slip39.Utils.random_share/0","doc":"Return a random share definition.\nThis is mainly used for testing.","ref":"Slip39.Utils.html#random_share/0"},{"type":"function","title":"Slip39.Utils.rnd_bytes/1","doc":"Randomness source for the module.\nIf deterministic testing is needed, one can configure the\nsource for test MIX_ENV here in future revision.","ref":"Slip39.Utils.html#rnd_bytes/1"},{"type":"module","title":"Slip39.Utils.Range","doc":"Contains helpers function to manipulate\nranges in the same way as the reference libary\nwriten in python.","ref":"Slip39.Utils.Range.html"},{"type":"function","title":"Slip39.Utils.Range.range/1","doc":"","ref":"Slip39.Utils.Range.html#range/1"},{"type":"function","title":"Slip39.Utils.Range.range/2","doc":"","ref":"Slip39.Utils.Range.html#range/2"},{"type":"function","title":"Slip39.Utils.Range.reverse/1","doc":"","ref":"Slip39.Utils.Range.html#reverse/1"},{"type":"module","title":"Slip39.WordList","doc":"","ref":"Slip39.WordList.html"},{"type":"function","title":"Slip39.WordList.english/0","doc":"","ref":"Slip39.WordList.html#english/0"},{"type":"function","title":"Slip39.WordList.word_list_map_by_idx/0","doc":"Returns a map than can be used to retrieve a word by its indice.","ref":"Slip39.WordList.html#word_list_map_by_idx/0"},{"type":"function","title":"Example - Slip39.WordList.word_list_map_by_idx/0","doc":"iex(1)> Slip39.WordList.word_list_map_by_idx()[0]\n    \"academic\"","ref":"Slip39.WordList.html#word_list_map_by_idx/0-example"},{"type":"function","title":"Slip39.WordList.word_list_map_by_string/0","doc":"Returns a map than can be used to retrive a word indices by its string.","ref":"Slip39.WordList.html#word_list_map_by_string/0"},{"type":"function","title":"Example - Slip39.WordList.word_list_map_by_string/0","doc":"iex(1)> Slip39.WordList.word_list_map_by_string()[\"academic\"]\n    0","ref":"Slip39.WordList.html#word_list_map_by_string/0-example"},{"type":"extras","title":"Slip39","doc":"# Slip39\n\nElixir implementation of the [SLIP-0039 : Shamir's Secret-Sharing for Mnemonic Codes](https://github.com/satoshilabs/slips/blob/master/slip-0039.md).\n\nThis implementation is largely inspired by the [reference implementation](http://github.com/trezor/python-shamir-mnemonic/).\n\nThis work is very in progress. Any contribution is welcome.","ref":"readme.html"},{"type":"extras","title":"Installation - Slip39","doc":"```elixir\ndef deps do\n  [\n    {:slip39, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Sample usage - Slip39","doc":"```elixir\niex(1)> Mix.install([ {:slip39, \"~> 0.1.0\"}])\n:ok\niex(2)> Slip39.generate_mnemonics!(2,5,\"My super hidden secret\")\n[\n  [\"acid smug academic acid argue forbid lobe spill elder mayor submit huge gray vintage fiscal fortune total mailman inherit texture exhaust float fake flea galaxy\",\n   \"acid smug academic agency artwork medical born clogs rescue cover moisture fiscal floral traffic moisture rescue clogs suitable inside emphasis overall shrimp hormone webcam dominant\",\n   \"acid smug academic always arena vexed rocky devote parcel ending enlarge busy aquatic award secret often glance corner income platform furl kidney actress nylon estimate\",\n   \"acid smug academic aquatic apart chest dance secret flip temple activity clogs deal believe adequate justice painting jerky hush auction medal unfold duckling dragon database\",\n   \"acid smug academic axis aunt else victim jewelry detect cards tidy temple bolt location human realize type lying join husky syndrome fitness cover belong quick\"]\n]\n\niex(3)> mnemonics = [\"acid smug academic always arena vexed rocky devote parcel ending enlarge busy aquatic award secret often glance corner income platform furl kidney actress nylon estimate\", \n...(3)> \"acid smug academic axis aunt else victim jewelry detect cards tidy temple bolt location human realize type lying join husky syndrome fitness cover belong quick\"]\niex(4)> mnemonics |> Slip39.combine_mnemonics()\n\"My super hidden secret\"\n\n```","ref":"readme.html#sample-usage"},{"type":"extras","title":"DISCLAIMER - Slip39","doc":"This module is supplied as is. Since it has not been audited and can\ncontains bugs, it should not be used to manipulate valuable secrets. If you decide to\nignore this warning, use basic OPSEC common sense and, at the very least, use a\ncomputer booted on a USB key, then taken offline during calls to the functions of this\nmodule. In addition, each mnemonic generated must never be stored in an electronic format\nand must be carefully double-checked. In any case, its/their authors cannot be held responsible\nfor any loss of data or its financial consequences resulting from the direct or indirect\nuse of this module.","ref":"readme.html#disclaimer"},{"type":"extras","title":"How to contribute - Slip39","doc":"I'm a beginner/mid-level Elixir developer, so please feel free to help improving this module. Here are some improvement ideas : \n\n* Some code parts are too much copy/pasted from reference implementation and should be refactored use more Elixir specific\nsyntax and constructs\n* I'm raising a lot of exception : I thing this gives simplier code. I'm not yet sure if it respects Elixir coding guidelines and we should switch to non raising function pattern (ie, returning `{:ok, value}` or `{:error, reason}`). I'm afraid this would lead to more complicated/unreadable code for not much benefits. Any input (for example showing me and example library) welcome.","ref":"readme.html#how-to-contribute"}],"content_type":"text/markdown"}